﻿using System;
using System.Text.RegularExpressions;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace TestProject
{
    /// <summary>
    /// 이미지 DPI 헬퍼
    /// </summary>
    public static class ImageDPIHelper
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 최적 스케일 구하기 - GetBestScale(pixelCountPerDIP)

        /// <summary>
        /// 최적 스케일 구하기
        /// </summary>
        /// <param name="pixelCountPerDIP">DIP당 픽셀 카운트</param>
        /// <returns>최적 스케일</returns>
        public static int GetBestScale(double pixelCountPerDIP)
        {
            int currentScale = (int)(pixelCountPerDIP * 100);

            int bestScale;

            if(currentScale > 200)
            {
                bestScale = 400;
            }
            else if(currentScale > 100)
            {
                bestScale = 200;
            }
            else
            {
                bestScale = 100;
            }

            return bestScale;
        }

        #endregion
        #region 희망 이미지 URL 구하기 - GetDesiredImageURL(image)

        /// <summary>
        /// 희망 이미지 URL 구하기
        /// </summary>
        /// <param name="image">이미지</param>
        /// <returns>희망 이미지 URL</returns>
        public static string GetDesiredImageURL(Image image)
        {            
            DpiScale dpiScale = VisualTreeHelper.GetDpi(image);

            int bestScale = ImageDPIHelper.GetBestScale(dpiScale.PixelsPerDip);

            string sourceURL = image.Source.ToString();

            string imagePattern = Regex.Replace(sourceURL, ".scale-[0-9]{3}.", ".scale-{0}.");

            string newImagePath = null;

            if(imagePattern != null)
            {
                newImagePath = string.Format(imagePattern, bestScale);
            }

            return newImagePath;
        }

        #endregion
        #region 이미지 업데이트하기 - UpdateImage(image, uriString)

        /// <summary>
        /// 이미지 업데이트하기
        /// </summary>
        /// <param name="image">이미지</param>
        /// <param name="uriString">URI 문자열</param>
        public static void UpdateImage(Image image, string uriString)
        {
            Uri uri = new Uri(uriString, UriKind.RelativeOrAbsolute);

            BitmapImage bitmapImage = new BitmapImage(uri);

            image.Source = bitmapImage;
        }

        #endregion
    }
}