﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            Loaded                += Window_Loaded;
            this.image.DpiChanged += image_DpiChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 윈도우 로드시 처리하기 - Window_Loaded(sender, e)

        /// <summary>
        /// 윈도우 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            UpdateImage(this.image);
        }

        #endregion
        #region 이미지 DPI 변경시 처리하기 - image_DpiChanged(sender, e)

        /// <summary>
        /// 이미지 DPI 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void image_DpiChanged(object sender, RoutedEventArgs e)
        {
            Image image = sender as Image;

            UpdateImage(image);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 이미지 업데이트하기 - UpdateImage(image)

        /// <summary>
        /// 이미지 업데이트하기
        /// </summary>
        /// <param name="image">이미지</param>
        private void UpdateImage(Image image)
        {
            string newImageURL = ImageDPIHelper.GetDesiredImageURL(image);

            ImageDPIHelper.UpdateImage(image, newImageURL);

            this.imageTextBlock.Text = $"이미지 : {newImageURL}, 화면 DPI : {(VisualTreeHelper.GetDpi(image).PixelsPerDip * 100)}";
        }

        #endregion
    }
}